""" 
from https://github.com/keithito/tacotron 
"""

'''
Cleaners are transformations that run over the input text at both training and eval time.

Cleaners can be selected by passing a comma-delimited list of cleaner names as the "cleaners"
hyperparameter. Some cleaners are English-specific. You'll typically want to use:
  1. "english_cleaners" for English text
  2. "transliteration_cleaners" for non-English text that can be transliterated to ASCII using
     the Unidecode library (https://pypi.python.org/pypi/Unidecode)
  3. "basic_cleaners" if you do not want to transliterate (in this case, you should also update
     the symbols in symbols.py to match your data).
'''


# Regular expression matching whitespace:
import re
from unidecode import unidecode
from .numbers import normalize_numbers
_whitespace_re = re.compile(r'\s+')

# List of (regular expression, replacement) pairs for abbreviations:
_abbreviations = [(re.compile('\\b%s\\.' % x[0], re.IGNORECASE), x[1]) for x in [
    ('mrs', 'misess'),
    ('mr', 'mister'),
    ('dr', 'doctor'),
    ('st', 'saint'),
    ('co', 'company'),
    ('jr', 'junior'),
    ('maj', 'major'),
    ('gen', 'general'),
    ('drs', 'doctors'),
    ('rev', 'reverend'),
    ('lt', 'lieutenant'),
    ('hon', 'honorable'),
    ('sgt', 'sergeant'),
    ('capt', 'captain'),
    ('esq', 'esquire'),
    ('ltd', 'limited'),
    ('col', 'colonel'),
    ('ft', 'fort'),
]]


def expand_abbreviations(text):
    for regex, replacement in _abbreviations:
        text = re.sub(regex, replacement, text)
    return text


def expand_numbers(text):
    return normalize_numbers(text)


def lowercase(text):
    return text.lower()


def collapse_whitespace(text):
    return re.sub(_whitespace_re, ' ', text)


def convert_to_ascii(text):
    return unidecode(text)


def basic_cleaners(text):
    '''Basic pipeline that lowercases and collapses whitespace without transliteration.'''
    text = lowercase(text)
    text = collapse_whitespace(text)
    return text


def transliteration_cleaners(text):
    '''Pipeline for non-English text that transliterates to ASCII.'''
    text = convert_to_ascii(text)
    text = lowercase(text)
    text = collapse_whitespace(text)
    return text


def english_cleaners(text):
    '''Pipeline for English text, including number and abbreviation expansion.'''
    text = convert_to_ascii(text)
    text = lowercase(text)
    text = expand_numbers(text)
    text = expand_abbreviations(text)
    text = collapse_whitespace(text)
    return text



import os

from setuptools import find_packages, setup

requirements={
    "infer": [
        "numpy>=1.24.3",
        "scipy>=1.10.1",
        "torch>=2.1",
        "torchaudio",
        "soundfile>=0.12.0",
        "librosa>=0.10.0",
        "scikit-learn",
        "numba==0.58.1",
        "inflect>=5.6.0",
        "tqdm>=4.64.1",
        "pyyaml>=6.0",
        "transformers==4.26.1",
        "yacs",
        "g2p_en",
        "jieba",
        "pypinyin",
        "streamlit",
        "pandas>=1.4,<2.0",
    ],
    "openai": [
        "fastapi",
        "python-multipart",
        "uvicorn[standard]",
        "pydub",
    ],
    "train": [
        "jsonlines",
        "praatio",
        "pyworld",
        "flake8",
        "flake8-bugbear",
        "flake8-comprehensions",
        "flake8-executable",
        "flake8-pyi",
        "mccabe",
        "pycodestyle",
        "pyflakes",
        "tensorboard",
        "einops",
        "matplotlib",
    ]
}

infer_requires = requirements["infer"]
openai_requires = requirements["infer"] + requirements["openai"]
train_requires = requirements["infer"] + requirements["train"]

VERSION = '0.2.0'

with open("README.md", "r", encoding="utf-8") as readme_file:
    README = readme_file.read()


setup(
    name="EmotiVoice",
    version=VERSION,
    url="https://github.com/netease-youdao/EmotiVoice",
    author="Huaxuan Wang",
    author_email="wanghx04@rd.netease.com",
    description="EmotiVoice 😊: a Multi-Voice and Prompt-Controlled TTS Engine",
    long_description=README,
    long_description_content_type="text/markdown",
    license="Apache Software License",
    # package
    packages=find_packages(),
    project_urls={
        "Documentation": "https://github.com/netease-youdao/EmotiVoice/wiki",
        "Tracker": "https://github.com/netease-youdao/EmotiVoice/issues",
        "Repository": "https://github.com/netease-youdao/EmotiVoice",
    },
    install_requires=infer_requires,
    extras_require={
        "train": train_requires,
        "openai": openai_requires,
    },
    python_requires=">=3.8.0",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Science/Research",
        "Operating System :: POSIX :: Linux",
        "License :: OSI Approved :: Apache Software License",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Multimedia :: Sound/Audio :: Speech",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
)